http

package
v0.1.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 30, 2025 License: BSD-3-Clause Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsIPWithPort added in v0.1.5

func IsIPWithPort(host string) (bool, string, string)

IsIPWithPort checks if the input is a valid IP address and extracts port if present

func MakeRequest

func MakeRequest(client *http.Client, cfg flags.Config, url string) (int, string, []byte, map[string][]string, error)

MakeRequest sends an HTTP request to the provided URL and returns status code, status, body, headers, and error

func NewClient

func NewClient(cfg flags.Config) (*http.Client, error)

NewClient creates a new HTTP client with the given configuration

func NewClientWithTimeout added in v0.1.6

func NewClientWithTimeout(cfg flags.Config, timeout time.Duration) (*http.Client, error)

NewClientWithTimeout creates a new HTTP client with a custom timeout

Types

This section is empty.

Jump to