Documentation
¶
Index ¶
- func IsIPWithPort(host string) (bool, string, string)
- func MakeRequest(client *http.Client, cfg flags.Config, url string) (int, string, []byte, map[string][]string, error)
- func NewClient(cfg flags.Config) (*http.Client, error)
- func NewClientWithTimeout(cfg flags.Config, timeout time.Duration) (*http.Client, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsIPWithPort ¶ added in v0.1.5
IsIPWithPort checks if the input is a valid IP address and extracts port if present
func MakeRequest ¶
func MakeRequest(client *http.Client, cfg flags.Config, url string) (int, string, []byte, map[string][]string, error)
MakeRequest sends an HTTP request to the provided URL and returns status code, status, body, headers, and error
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.